
# coding: utf-8

# In[1]:

#modules 
get_ipython().magic('matplotlib inline')
import scipy
import numpy as np
import datetime 
import statistics
import glob
import xarray as xr
import time
import math
import warnings
import os

import pandas as pd 
import matplotlib.pyplot as plt 


# ## Version du code sans les barres d'erreurs 
# 

# In[2]:

base_csv = '/home/hiault/Python_stage/Data/ACE_FTS_V5/ACEFTS_L2_v5p0_CHF3.csv'
csv_base = pd.read_csv(base_csv, sep=',', header=0)


# In[3]:


def create_dataframe(csv_base, lat1, lat2, long1, long2):
    err_value = -999
    err_value2 = -888
    ppt = 10**12

    df = csv_base.loc[(csv_base['latitude'].between(lat1, lat2)) & (csv_base['longitude'].between(long1, long2))
                      & (csv_base['CHF3_error'] != err_value) & (csv_base['CHF3_error'] != err_value2)]

    df_new = df.loc[:, ['altitude', 'year', 'month', 'day', 'CHF3', 'CHF3_error']]
    df_new['CHF3_ppt'] = df_new['CHF3'] * ppt
    df_new['CHF3_error_ppt'] = df_new['CHF3_error'] * ppt

    df_new = df_new.loc[(df_new['CHF3_ppt'].between(0, 45)) & (df_new['altitude'] <= 40.5)]
    
    return df_new

# Zone Suisse
lat1 = 40
lat2 = 60
long1 = -5
long2 = 15

df1_new = create_dataframe(csv_base, lat1, lat2, long1, long2)

# Zone Ireland
lat1 = 40
lat2 = 60
long1 = -25
long2 = 5

df2_new = create_dataframe(csv_base, lat1, lat2, long1, long2)


# In[4]:



start_year = 2007
end_year = 2020
years = list(range(start_year, end_year + 1))
df_resultats = {}

for year in years:
    df_year = df1_new.loc[df1_new['year'] == year]
    unique_values = df_year['altitude'].unique()
    unique_values.sort()
    
    resultats = []
    
    for value in unique_values:
        mean_value = df_year.loc[df_year['altitude'] == value, 'CHF3_ppt'].mean()
        resultats.append(mean_value)
    
    df_result = pd.DataFrame(resultats, columns=['mean_{}_ppt'.format(year)])
    df_result['altitude'] = unique_values
    df_result = df_result.set_index('altitude', drop=True)
    
    df_resultats['df_resultats_{}'.format(year)] = df_result


#output = '/home/hiault/Python_stage/out/'
output = '/home/hiault/Python_stage/out/new_figures_TFE/'
fig, ax = plt.subplots(figsize=(30,20))

colors = [ '#d62728', '#9467bd',
          '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#17becf',
          '#1f4f99', '#e98125', '#3f963f', '#d43635', '#7b4fa6',
          '#724437', '#c3699b' ]

# '#1f77b4', '#ff7f0e', '#2ca02c', '#555555', '#89a830'


labels = [ '2007', '2008',
          '2009', '2010', '2011', '2012', '2013',
          '2014', '2015', '2016', '2017', '2018',
          '2019', '2020']

# '2004', '2005', '2006', '2021', '2022'


for i, year in enumerate(years):
    df_result = df_resultats['df_resultats_{}'.format(year)]
    axis_data = df_result['mean_{}_ppt'.format(year)].values
    ax.plot(axis_data, df_result.index, '-o',markersize = 10, color=colors[i], label=labels[i])

ax.set_title('Evolution of HFC-23 mean mixing ratio vs altitude (Switzerland area) \n(ACE-FTS data)', fontsize=32)
ax.set_xlabel('Volume mixing ratio (ppt)', fontsize=36)
ax.set_ylabel('Altitude (km)', fontsize=36)
ax.legend(loc='best')

ax.tick_params(axis='both', which='major', direction='inout', length=14, width=2, top=1, bottom=1, left=1, right=1, 
               labelsize=36)
ax.tick_params(axis='both', which='minor', direction='inout', length=8, width=2, top=1, bottom=1, left=1, right=1, 
               labelsize=36)
plt.rc('font', **{'size':'28'})

fig.savefig(output + 'CHF3_vs_altitude_Switzerland_area_ACE.png', dpi=300)
plt.show()


# ## Ireland 

# In[5]:


start_year = 2007
end_year = 2020
years = list(range(start_year, end_year + 1))
df_resultats = {}

for year in years:
    df_year = df2_new.loc[df2_new['year'] == year]
    unique_values = df_year['altitude'].unique()
    unique_values.sort()
    
    resultats = []
    
    
    
    for value in unique_values:
        mean_value = df_year.loc[df_year['altitude'] == value, 'CHF3_ppt'].mean()
        resultats.append(mean_value)
    
    df_result = pd.DataFrame(resultats, columns=['mean_{}_ppt'.format(year)])
    df_result['altitude'] = unique_values
    df_result = df_result.set_index('altitude', drop=True)
    
    df_resultats['df_resultats_{}'.format(year)] = df_result


#output = '/home/hiault/Python_stage/out/'
output = '/home/hiault/Python_stage/out/new_figures_TFE/'
fig, ax = plt.subplots(figsize=(30,20))

colors = [ '#d62728', '#9467bd',
          '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#17becf',
          '#1f4f99', '#e98125', '#3f963f', '#d43635', '#7b4fa6',
          '#724437', '#c3699b' ]

# '#1f77b4', '#ff7f0e', '#2ca02c','#555555', '#89a830'

labels = [ '2007', '2008',
          '2009', '2010', '2011', '2012', '2013',
          '2014', '2015', '2016', '2017', '2018',
          '2019', '2020' ]

# '2004', '2005', '2006', '2021', '2022'

for i, year in enumerate(years):
    df_result = df_resultats['df_resultats_{}'.format(year)]
    axis_data = df_result['mean_{}_ppt'.format(year)].values
    ax.plot(axis_data, df_result.index, '-o', markersize=10,  color=colors[i], label=labels[i])

ax.set_title('Evolution of HFC-23 mean mixing ratio vs altitude (Ireland area) \n(ACE-FTS data)', fontsize=32)
ax.set_xlabel('Volume Mixing ratio (ppt)', fontsize=36)
ax.set_ylabel('Altitude (km)', fontsize=36)
ax.legend(loc='best')

ax.tick_params(axis='both', which='major', direction='inout', length=14, width=2, top=1, bottom=1, left=1, right=1, 
               labelsize=36)
ax.tick_params(axis='both', which='minor', direction='inout', length=8, width=2, top=1, bottom=1, left=1, right=1, 
               labelsize=36)
plt.rc('font', **{'size':'28'})
fig.savefig(output + 'CHF3_vs_altitude_Ireland_area_ACE.png', dpi=300)
plt.show()


# # Code avec les barres d'erreurs 
# 

# In[15]:



start_year = 2004
end_year = 2022
years = list(range(start_year, end_year + 1))

df_resultats = {}

for year in years:
    df_year = df1_new.loc[df1_new['year'] == year]
    unique_values = df_year['altitude'].unique()
    unique_values.sort()
    
    resultats = []
    errors = []
    
    for value in unique_values:
        mean_value = df_year.loc[df_year['altitude'] == value, 'CHF3_ppt'].mean()
        resultats.append(mean_value)
        
        error_value = df_year.loc[df_year['altitude'] == value, 'CHF3_error_ppt'].mean()
        errors.append(error_value)
    
    df_result = pd.DataFrame({'mean_{}_ppt'.format(year): resultats, 'error_{}_ppt'.format(year): errors})
    df_result['altitude'] = unique_values
    df_result = df_result.set_index('altitude', drop=True)
    
    df_resultats['df_resultats_{}'.format(year)] = df_result

output = '/home/hiault/Python_stage/out/'
fig, ax = plt.subplots(figsize=(30, 20))

colors = ['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728', '#9467bd',
          '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#17becf',
          '#1f4f99', '#e98125', '#3f963f', '#d43635', '#7b4fa6',
          '#724437', '#c3699b', '#555555', '#89a830']

labels = ['2004', '2005', '2006', '2007', '2008',
          '2009', '2010', '2011', '2012', '2013',
          '2014', '2015', '2016', '2017', '2018',
          '2019', '2020', '2021', '2022']

for i, year in enumerate(years):
    df_result = df_resultats['df_resultats_{}'.format(year)]
    axis_data = df_result['mean_{}_ppt'.format(year)].values
    error_data = df_result['error_{}_ppt'.format(year)].values
    ax.errorbar(axis_data, df_result.index, xerr=error_data, fmt='o-', markersize=12, color=colors[i],
                ecolor='lightgray', capsize=4, label=labels[i])

ax.set_title('Evolution of HFC-23 mean abundance vs altitude (Switzerland area) \n(ACE-FTS data)', fontsize=40)
ax.set_xlabel('ppt', fontsize=36)
ax.set_ylabel('Altitude (km)', fontsize=36)
ax.legend(loc='best')

ax.tick_params(axis='both', which='major', direction='inout', length=14, width=2, top=1, bottom=1, left=1, right=1,
               labelsize=36)
ax.tick_params(axis='both', which='minor', direction='inout', length=8, width=2, top=1, bottom=1, left=1, right=1,
               labelsize=36)
plt.rc('font', **{'size': '28'})
#fig.savefig(output + 'CHF3_vs_altitude_Switzerland_area_with_errors_ACE.png', dpi=300)
plt.show()


# In[16]:


start_year = 2004
end_year = 2022
years = list(range(start_year, end_year + 1))

df_resultats = {}

for year in years:
    df_year = df2_new.loc[df2_new['year'] == year]
    unique_values = df_year['altitude'].unique()
    unique_values.sort()
    
    resultats = []
    errors = []
    
    for value in unique_values:
        mean_value = df_year.loc[df_year['altitude'] == value, 'CHF3_ppt'].mean()
        resultats.append(mean_value)
        
        error_value = df_year.loc[df_year['altitude'] == value, 'CHF3_error_ppt'].mean()
        errors.append(error_value)
    
    df_result = pd.DataFrame({'mean_{}_ppt'.format(year): resultats, 'error_{}_ppt'.format(year): errors})
    df_result['altitude'] = unique_values
    df_result = df_result.set_index('altitude', drop=True)
    
    df_resultats['df_resultats_{}'.format(year)] = df_result

output = '/home/hiault/Python_stage/out/'
fig, ax = plt.subplots(figsize=(30, 20))

colors = ['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728', '#9467bd',
          '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#17becf',
          '#1f4f99', '#e98125', '#3f963f', '#d43635', '#7b4fa6',
          '#724437', '#c3699b', '#555555', '#89a830']

labels = ['2004', '2005', '2006', '2007', '2008',
          '2009', '2010', '2011', '2012', '2013',
          '2014', '2015', '2016', '2017', '2018',
          '2019', '2020', '2021', '2022']

for i, year in enumerate(years):
    df_result = df_resultats['df_resultats_{}'.format(year)]
    axis_data = df_result['mean_{}_ppt'.format(year)].values
    error_data = df_result['error_{}_ppt'.format(year)].values
    ax.errorbar(axis_data, df_result.index, xerr=error_data, fmt='o-', markersize=12, color=colors[i],
                ecolor='lightgray', capsize=4, label=labels[i])

ax.set_title('Evolution of HFC-23 mean abundance vs altitude (Switzerland area) \n(ACE-FTS data)', fontsize=40)
ax.set_xlabel('ppt', fontsize=36)
ax.set_ylabel('Altitude (km)', fontsize=36)
ax.legend(loc='best')

ax.tick_params(axis='both', which='major', direction='inout', length=14, width=2, top=1, bottom=1, left=1, right=1,
               labelsize=36)
ax.tick_params(axis='both', which='minor', direction='inout', length=8, width=2, top=1, bottom=1, left=1, right=1,
               labelsize=36)
plt.rc('font', **{'size': '28'})
#fig.savefig(output + 'CHF3_vs_altitude_Ireland_area_with_errors_ACE.png', dpi=300)
plt.show()

